@@ -24,6 +24,7 @@ def filed(key,inquire=[]):
         'entityHost': kai.machine(inquire).inquireEntity,
         'serviceKpiId': kai.machine(inquire).inquireServiceKpi,
         'businessKpiIdAndServiceId':kai.machine(inquire).inquireBusinessKPIAndServiceId,
+        'ServiceBusinessID':kai.machine(inquire).ServiceBusiness,
         'pensInfo':kai.machine(inquire).inquirePens,
         'testHostIP':ip.date().getTestHostIP,
         'rarserRuleName': objectManager.date().getRuleNameId,
@@ -35,6 +36,7 @@ def filed(key,inquire=[]):
         'indexList_as':index.date().getIndexTypeAs,
         'DateTime':timestamp.date().getDateTime,
         'agentPort': agent.machine(inquire).getAgentPort,
+        'AlertAgentPort': agent.machine(inquire).getIntPort,
         'intPort':agent.machine(inquire).getIntPort,
         'adminID':id.date().getAdminID,
         'DefaultLogGroupID':id.date().getDefaultLogGroupID,
